@@ -5,7 +5,7 @@ check_workspace_path()
 from autoarray import preprocess
 from autoarray.dataset.imaging import Imaging
 from autoarray.dataset.interferometer import Interferometer
-from autoarray.mask.mask import Mask
+from autoarray.mask.mask_2d import Mask2D
 from autoarray.operators.convolver import Convolver
 from autoarray.inversion import pixelizations as pix, regularization as reg
 from autoarray.inversion.pixelizations import SettingsPixelization
@@ -43,6 +43,7 @@ from autogalaxy.pipeline.phase.extensions.inversion_phase import (
     InversionPhase,
     ModelFixingHyperPhase,
 )
+from autogalaxy.pipeline.pipeline import PipelineDataset
 from autogalaxy.plane.plane import Plane
 from autogalaxy.profiles import (
     light_profiles as lp,
@@ -82,7 +83,5 @@ from .pipeline.phase.imaging.phase import PhaseImaging
 from .pipeline.phase.interferometer.phase import PhaseInterferometer
 from .pipeline.phase.extensions.stochastic_phase import StochasticPhase
 from .pipeline.phase.phase_galaxy import PhaseGalaxy
-from .pipeline.pipeline import PipelineDataset, PipelinePositions
 
-
-__version__ = '1.5.12'
+__version__ = '1.6.1'
