@@ -19,7 +19,7 @@ class MaskedImaging(imaging.MaskedImaging):
         ----------
         imaging: im.Imaging
             The imaging data all in 2D (the image, noise-map, PSF, etc.)
-        mask: msk.Mask
+        mask: msk.Mask2D
             The 2D mask that is applied to the image.
         sub_size : int
             The size of the sub-grid used for each lens SubGrid. E.g. a value of 2 grid each image-pixel on a 2x2 \
