@@ -67,7 +67,7 @@ class PhaseInterferometer(dataset.PhaseDataset):
         Parameters
         ----------
         positions
-        mask: Mask
+        mask: Mask2D
             The default masks passed in by the pipeline
         dataset: im.Interferometer
             An masked_interferometer that has been masked
