@@ -165,14 +165,14 @@ class PhaseGalaxy(abstract.AbstractPhase):
         self.sub_size = sub_size
         self.pixel_scales_interp = pixel_scales_interp
 
-    def run(self, galaxy_data, mask, info=None, results=None):
+    def run(self, galaxy_data, mask, info=None, pickle_files=None, results=None):
         """
         Run this phase.
 
         Parameters
         ----------
         galaxy_data
-        mask: Mask
+        mask: Mask2D
             The default masks passed in by the pipeline
         results: autofit.tools.pipeline.ResultsCollection
             An object describing the results of the last phase or None if no phase has
@@ -204,7 +204,7 @@ class PhaseGalaxy(abstract.AbstractPhase):
         Parameters
         ----------
         galaxy_data
-        mask: Mask
+        mask: Mask2D
             The default masks passed in by the pipeline
         results: autofit.tools.pipeline.ResultsCollection
             The result from the previous phase
