@@ -3,14 +3,14 @@
 Tutorial 3: Complex Source
 ==========================
 
-Up to now, we've not paid much attention to the source-galaxy's morphology. We've assumed its a single-component
+Up to now, we`ve not paid much attention to the source-galaxy`s morphology. We`ve assumed its a single-component
 exponential profile, which is a fairly crude assumption. A quick look at any image of a real galaxy reveals a
 wealth of different structures that could be present - bulges, disks, bars, star-forming knots and so on. Furthermore,
 there could be more than one source-galaxy!
 
 In this example, we'll explore how far we can get trying to_fit a complex source using a pipeline. Fitting complex
-source's is an exercise in diminishing returns. Each component we add to our source model brings with it an
-extra 5-7, parameters. If there are 4 components, or multiple _Galaxy_'s we're quickly entering the somewhat nasty
+source`s is an exercise in diminishing returns. Each component we add to our source model brings with it an
+extra 5-7, parameters. If there are 4 components, or multiple `Galaxy``s we`re quickly entering the somewhat nasty
 regime of 30-40+ parameters in our non-linear search. Even with a pipeline, that is a lot of parameters to fit!
 """
 
@@ -37,11 +37,11 @@ import autolens.plot as aplt
 
 # %%
 """
-We'll use new strong lensing data, where:
+we'll use new strong lensing data, where:
 
- - The lens galaxy's light is omitted.
- - The lens galaxy's _MassProfile_ is an _EllipticalIsothermal_.
- - The source galaxy's _LightProfile_ is four _EllipticalSersic_'s.
+ - The lens galaxy`s light is omitted.
+ - The lens galaxy`s `MassProfile` is an `EllipticalIsothermal`.
+ - The source galaxy`s `LightProfile` is four `EllipticalSersic``..
 """
 
 # %%
@@ -65,7 +65,7 @@ of its light in the central regions of the image, so lets use a circular mask.
 """
 
 # %%
-mask = al.Mask.circular(
+mask = al.Mask2D.circular(
     shape_2d=imaging.shape_2d, pixel_scales=imaging.pixel_scales, radius=3.0
 )
 
@@ -73,19 +73,19 @@ aplt.Imaging.subplot_imaging(imaging=imaging, mask=mask)
 
 # %%
 """
-Yep, that's a pretty complex source. There are clearly more than 4 peaks of light - I wouldn't like to guess how many
-sources of light there truly is! You'll also notice I omitted the lens galaxy's light for this system. This is to 
-keep the number of parameters down and the phases running fast, but we wouldn't get such a luxury for a real galaxy.
+Yep, that`s a pretty complex source. There are clearly more than 4 peaks of light - I wouldn`t like to guess how many
+sources of light there truly is! You`ll also notice I omitted the lens galaxy`s light for this system. This is to 
+keep the number of parameters down and the phases running fast, but we wouldn`t get such a luxury for a real galaxy.
 """
 
 # %%
 """
 __Settings__
 
-The _SettingsPhaseImaging_ describe how the model is fitted to the data in the log likelihood function. We discussed
+The `SettingsPhaseImaging` describe how the model is fitted to the data in the log likelihood function. We discussed
 these in chapter 2, and a full description of all settings can be found in the example script:
 
- 'autolens_workspace/examples/model/customize/settings.py'.
+ `autolens_workspace/examples/model/customize/settings.py`.
 
 The settings chosen here are applied to all phases in the pipeline.
 """
@@ -101,7 +101,7 @@ __Pipeline_Setup_And_Tagging__:
 
 For this pipeline the pipeline setup customizes:
 
- - If there is an _ExternalShear_ in the mass model or not.
+ - If there is an `ExternalShear` in the mass model or not.
 """
 
 # %%
@@ -120,22 +120,20 @@ setup = al.SetupPipeline(
 """
 __Pipeline Creation__
 
-To create a _Pipeline_, we call a 'make_pipeline' function, which is written in its own Python script: 
+To create a `Pipeline`, we call a `make_pipeline` function, which is written in its own Python script: 
 
- 'tutorial_3_complex_source.py'. 
+ `tutorial_3_complex_source.py`. 
 
-Before we check it out, lets get the pipeline running, by importing the script, running the 'make_pipeline' function
-to create the _Pipeline_ object and calling that objects 'run' function.
+Before we check it out, lets get the pipeline running, by importing the script, running the `make_pipeline` function
+to create the `Pipeline` object and calling that objects `run` function.
 
-The 'folders' below specify the path the pipeline results are written to, which is:
+The `folders` below specify the path the pipeline results are written to, which is:
 
- 'autolens_workspace/output/howtolens/c3_t3_complex_source/pipeline_name/setup_tag/phase_name/settings_tag'
+ `autolens_workspace/output/howtolens/c3_t3_complex_source/pipeline_name/setup_tag/phase_name/settings_tag`
 """
 
 # %%
-from howtolens.chapter_3_pipelines import (
-    tutorial_3_pipeline_complex_source,
-)
+from howtolens.chapter_3_pipelines import tutorial_3_pipeline_complex_source
 
 pipeline_complex_source = tutorial_3_pipeline_complex_source.make_pipeline(
     setup=setup, settings=settings
@@ -146,17 +144,17 @@ pipeline_complex_source = tutorial_3_pipeline_complex_source.make_pipeline(
 
 # %%
 """
-Okay, so with 4 sources, we still couldn't get a good a fit to the source that didn't leave residuals. However, I 
-actually simulated the lens with 4 sources. This means that there is a 'perfect fit' somewhere in parameter space 
+Okay, so with 4 sources, we still couldn`t get a good a fit to the source that didn`t leave residuals. However, I 
+actually simulated the lens with 4 sources. This means that there is a `perfect fit` somewhere in parameter space 
 that we unfortunately missed using the pipeline above.
 
-Lets confirm this, by manually fitting the _Imaging_ data with the true input model.
+Lets confirm this, by manually fitting the `Imaging` data with the true input model.
 """
 
 # %%
 masked_imaging = al.MaskedImaging(
     imaging=imaging,
-    mask=al.Mask.circular(
+    mask=al.Mask2D.circular(
         shape_2d=imaging.shape_2d, pixel_scales=imaging.pixel_scales, radius=3.0
     ),
 )
@@ -237,7 +235,7 @@ The morale of this story is that if the source morphology is complex, there is n
 fit it. For this tutorial, this was true even though our source model could actually fit the data perfectly. For real 
 lenses, the source will be *even more complex* and there is even less hope of getting a good fit :(
 
-But fear not, __PyAutoLens__ has you covered. In chapter 4, we'll introduce a completely new way to model the source 
+But fear not, ``.yAutoLens__ has you covered. In chapter 4, we'll introduce a completely new way to model the source 
 galaxy, which addresses the problem faced here. But before that, in the next tutorial we'll discuss how we actually 
 pass priors in a pipeline.
 """
