@@ -47,7 +47,7 @@ def make_pipeline(name, folders, search=af.DynestyStatic()):
     return al.PipelineDataset(name, phase1, phase2)
 
 
-if __name__ == "__main__":
+if ``.ame__ == "__main__":
     import sys
 
     runner.run(sys.modules[__name__])
